@@ -3,26 +3,20 @@ Twisted server
 """
 
 __author__ = 'VMware, Inc.'
-__copyright__ = 'Copyright 2015, 2017 VMware, Inc.  All rights reserved. -- VMware Confidential'  # pylint: disable=line-too-long
+__copyright__ = 'Copyright 2015, 2017, 2021 VMware, Inc.  All rights reserved. -- VMware Confidential'  # pylint: disable=line-too-long
 
 import threading
 import six
 import warnings
 
-with warnings.catch_warnings():
-    # Disable DeprecationWarning as twisted uses md5 instead of hashlib
-    warnings.filterwarnings("ignore", category=DeprecationWarning)
-    # Disable SyntaxWarning as twisted uses assert (oldChild.parentNode is self)
-    # which is always true
-    warnings.filterwarnings("ignore", category=SyntaxWarning)
-    import twisted
-    # Without adding this explicit import, the ssl part of twisted
-    # doesn't get initialized
-    import twisted.internet.ssl
-    from twisted.internet import defer
-    from twisted.internet.protocol import Protocol, Factory
-    from twisted.web.resource import Resource
-    from twisted.web.server import Site
+import twisted
+# Without adding this explicit import, the ssl part of twisted
+# doesn't get initialized
+import twisted.internet.ssl
+from twisted.internet import defer
+from twisted.internet.protocol import Protocol, Factory
+from twisted.web.resource import Resource
+from twisted.web.server import Site
 
 from vmware.vapi.server.server_interface import ServerInterface
 from vmware.vapi.lib.addr_url_parser import parse_addr_url
